@@ -115,7 +115,7 @@ def sections_to_text(doc, sections, citations: ArticleCitations, params):
     ref2citations = {}
     if params.citations and citations:
         for ref, citation in citations.additional_properties.items():
-            ref2citations[ref] = citation_to_metadata(citation)
+            ref2citations['#' + ref] = citation_to_metadata(citation)
     if sections:
         text_buf = []
         sentences = []
@@ -163,6 +163,7 @@ def add_references(sentence: TextWithRefs, text_buf: List[str], ref2citations):
         for ref in sentence.refs:
             if ref.type == "bibr":
                 a = Annotation(label="Citation", labelName="citation",
+                               text=sentence.text[ref.start:ref.end],
                                start=start + ref.start, end=start + ref.end)
                 props = ref2citations.get(ref.target, None)
                 if props:
